Enum AttributesMismatch

pub enum AttributesMismatch {
Show 22 variants ParentHash(B256, B256), Timestamp(u64, u64), PrevRandao(B256, B256), MalformedBlockTransactions, MalformedAttributesTransaction, TransactionLen(usize, usize), TransactionContent(B256, B256), MissingAttributesEIP1559, MissingBlockEIP1559, InvalidExtraDataVersion, UnknownExtraDataDecodingError(EIP1559ParamError), InvalidEIP1559ParamsCombination, EIP1559Parameters(BaseFeeParams, BaseFeeParams), Transactions(u64, u64), GasLimit(u64, u64), MissingAttributesGasLimit, FeeRecipient(Address, Address), ParentBeaconBlockRoot(Option<B256>, Option<B256>), CanyonWithdrawalsNotEmpty, CanyonNotEmptyHash, BedrockWithdrawals, IsthmusMissingWithdrawalsRoot,
}
An enum over the type of mismatch between OpAttributesWithParent and a Block.

Variants



ParentHash(B256, B256)

The parent hash of the block does not match the parent hash of the attributes.



Timestamp(u64, u64)

The timestamp of the block does not match the timestamp of the attributes.



PrevRandao(B256, B256)

The prev randao of the block does not match the prev randao of the attributes.



MalformedBlockTransactions

The block contains malformed transactions. This is a bug - the transaction format should be checked before the consolidation step.



MalformedAttributesTransaction

There is a malformed transaction inside the attributes. This is a bug - the transaction format should be checked before the consolidation step.



TransactionLen(usize, usize)

A mismatch in the number of transactions contained in the attributes and the block.



TransactionContent(B256, B256)

A mismatch in the content of some transactions contained in the attributes and the block.



MissingAttributesEIP1559

The EIP1559 payload for the OpAttributesWithParent is missing when holocene is active.



MissingBlockEIP1559

The EIP1559 payload for the block is missing when holocene is active.



InvalidExtraDataVersion

The version in the extra data EIP1559 payload is incorrect. Should be 0.



UnknownExtraDataDecodingError(EIP1559ParamError)

An unknown extra data decoding error occurred.



InvalidEIP1559ParamsCombination

Holocene EIP1559 params cannot have a 0 denominator unless elasticity is also 0



EIP1559Parameters(BaseFeeParams, BaseFeeParams)

The EIP1559 base fee parameters of the attributes and the block don’t match



Transactions(u64, u64)

Transactions mismatch.



GasLimit(u64, u64)

The gas limit of the block does not match the gas limit of the attributes.



MissingAttributesGasLimit

The gas limit for the OpAttributesWithParent is missing.



FeeRecipient(Address, Address)

The fee recipient of the block does not match the fee recipient of the attributes.



ParentBeaconBlockRoot(Option<B256>, Option<B256>)

A mismatch in the parent beacon block root.



CanyonWithdrawalsNotEmpty

After the canyon hardfork, withdrawals cannot be empty.



CanyonNotEmptyHash

After the canyon hardfork, the withdrawals root must be the empty hash.



BedrockWithdrawals

In the bedrock hardfork, the attributes must has empty withdrawals.



IsthmusMissingWithdrawalsRoot

In the isthmus hardfork, the withdrawals root must be set.