pub enum BuildTaskError {
EngineBuildError(EngineBuildError),
ForkchoiceUpdateFailed(SynchronizeTaskError),
PayloadInsertionFailed(InsertTaskError),
GetPayloadFailed(RpcError<TransportErrorKind>),
DepositOnlyPayloadFailed,
DepositOnlyPayloadReattemptFailed,
HoloceneInvalidFlush,
FromBlock(FromBlockError),
MpscSend(SendError<OpExecutionPayloadEnvelope>),
}Expand description
An error that occurs when running the crate::SynchronizeTask.
Variants
EngineBuildError(EngineBuildError)
An error occurred when building the payload attributes in the engine.
ForkchoiceUpdateFailed(SynchronizeTaskError)
The initial forkchoice update call to the engine api failed.
PayloadInsertionFailed(InsertTaskError)
Impossible to insert the payload into the engine.
GetPayloadFailed(RpcError<TransportErrorKind>)
The get payload call to the engine api failed.
DepositOnlyPayloadFailed
A deposit-only payload failed to import.
DepositOnlyPayloadReattemptFailed
Failed to re-atttempt payload import with deposit-only payload.
HoloceneInvalidFlush
The payload is invalid, and the derivation pipeline must be flushed post-holocene.
FromBlock(FromBlockError)
Failed to convert a OpExecutionPayload to a L2BlockInfo.
MpscSend(SendError<OpExecutionPayloadEnvelope>)
Error sending the built payload envelope.