pub enum EngineKind {
Geth,
Reth,
Erigon,
}Expand description
Identifies the type of execution layer client for behavior customization.
Different execution clients may have slight variations in API behavior or supported features. This enum allows the engine to adapt its behavior accordingly, though as of v0.1.0, behavior is equivalent across all types.
Examples
use kona_engine::EngineKind;
use std::str::FromStr;
// Parse from string
let kind = EngineKind::from_str("geth").unwrap();
assert_eq!(kind, EngineKind::Geth);
// Display as string
assert_eq!(EngineKind::Reth.to_string(), "reth");Variants
Implementations
Sourceimpl EngineKind
impl EngineKind
Sourcepub const fn supports_post_finalization_elsync(self) -> bool
👎Deprecated since 0.1.0: Node behavior is now equivalent across all engine client types.
pub const fn supports_post_finalization_elsync(self) -> bool
Returns whether the engine client kind supports post finalization EL sync.