pub enum EngineTask {
Insert(InsertTask),
Build(BuildTask),
Consolidate(ConsolidateTask),
Finalize(FinalizeTask),
}Expand description
Tasks that may be inserted into and executed by the Engine.
Variants
Insert(InsertTask)
Inserts a payload into the execution engine.
Build(BuildTask)
Builds a new block with the given attributes, and inserts it into the execution engine.
Consolidate(ConsolidateTask)
Performs consolidation on the engine state, reverting to payload attribute processing
via the BuildTask if consolidation fails.
Finalize(FinalizeTask)
Finalizes an L2 block