pub enum EngineTaskErrorSeverity {
Temporary,
Critical,
Reset,
Flush,
}Expand description
The severity of an engine task error.
This is used to determine how to handle the error when draining the engine task queue.
Variants
Temporary
The error is temporary and the task is retried.
Critical
The error is critical and is propagated to the engine actor.
Reset
The error indicates that the engine should be reset.
Flush
The error indicates that the engine should be flushed.