pub enum EngineTaskErrors {
Insert(InsertTaskError),
Build(BuildTaskError),
Consolidate(ConsolidateTaskError),
Finalize(FinalizeTaskError),
}Expand description
An error that may occur during an EngineTask’s execution.
Variants
Insert(InsertTaskError)
An error that occurred while inserting a block into the engine.
Build(BuildTaskError)
An error that occurred while building a block.
Consolidate(ConsolidateTaskError)
An error that occurred while consolidating the engine state.
Finalize(FinalizeTaskError)
An error that occurred while finalizing an L2 block.