pub enum FinalizeTaskError {
BlockNotSafe,
BlockNotFound(u64),
FromBlock(FromBlockError),
TransportError(RpcError<TransportErrorKind>),
ForkchoiceUpdateFailed(SynchronizeTaskError),
}Expand description
An error that occurs when running the crate::FinalizeTask.
Variants
BlockNotSafe
The block is not safe, and therefore cannot be finalized.
BlockNotFound(u64)
The block to finalize was not found.
FromBlock(FromBlockError)
An error occurred while transforming the RPC block into L2BlockInfo.
TransportError(RpcError<TransportErrorKind>)
A temporary RPC failure.
ForkchoiceUpdateFailed(SynchronizeTaskError)
The forkchoice update call to finalize the block failed.