Struct ConsolidateTask

pub struct ConsolidateTask {
    pub client: Arc<EngineClient>,
    pub cfg: Arc<RollupConfig>,
    pub attributes: OpAttributesWithParent,
    pub is_attributes_derived: bool,
}
The ConsolidateTask attempts to consolidate the engine state using the specified payload attributes and the oldest unsafe head.

If consolidation fails, payload attributes processing is attempted using the BuildTask.

Fields

client: Arc<EngineClient>

The engine client.

cfg: Arc<RollupConfig>attributes: OpAttributesWithParent

The OpAttributesWithParent to instruct the execution layer to build.

is_attributes_derived: bool

Whether or not the payload was derived, or created by the sequencer.

Implementations

Source

impl ConsolidateTask

pub const fn new( client: Arc<EngineClient>, config: Arc<RollupConfig>, attributes: OpAttributesWithParent, is_attributes_derived: bool, ) -> Self

Creates a new ConsolidateTask.

pub async fn consolidate( &self, state: &mut EngineState, ) -> Result<(), ConsolidateTaskError>

Attempts consolidation on the engine state.