Struct Engine

pub struct Engine { /* private fields */ }
The Engine task queue.

Tasks of a shared EngineTask variant are processed in FIFO order, providing synchronization guarantees for the L2 execution layer and other actors. A priority queue, ordered by EngineTask’s Ord implementation, is used to prioritize tasks executed by the Engine::drain method.

Because tasks are executed one at a time, they are considered to be atomic operations over the EngineState, and are given exclusive access to the engine state during execution.

Tasks within the queue are also considered fallible. If they fail with a temporary error, they are not popped from the queue, the error is returned, and they are retried on the next call to Engine::drain.

Implementations

Source

impl Engine

pub fn new( initial_state: EngineState, state_sender: Sender<EngineState>, task_queue_length: Sender<usize>, ) -> Self

Creates a new Engine with an empty task queue and the passed initial EngineState.

pub const fn state(&self) -> &EngineState

Returns a reference to the inner EngineState.

pub fn state_subscribe(&self) -> Receiver<EngineState>

Returns a receiver that can be used to listen to engine state updates.

pub fn queue_length_subscribe(&self) -> Receiver<usize>

Returns a receiver that can be used to listen to engine queue length updates.

pub fn enqueue(&mut self, task: EngineTask)

Enqueues a new EngineTask for execution. Updates the queue length and notifies listeners of the change.

pub async fn reset( &mut self, client: Arc<EngineClient>, config: Arc<RollupConfig>, ) -> Result<(L2BlockInfo, BlockInfo, SystemConfig), EngineResetError>

Resets the engine by finding a plausible sync starting point via find_starting_forkchoice. The state will be updated to the starting point, and a forkchoice update will be enqueued in order to reorg the execution layer.

pub fn clear(&mut self)

Clears the task queue.

pub async fn drain(&mut self) -> Result<(), EngineTaskErrors>

Attempts to drain the queue by executing all EngineTasks in-order. If any task returns an error along the way, it is not popped from the queue (in case it must be retried) and the error is returned.