Struct EngineState

pub struct EngineState {
    pub sync_state: EngineSyncState,
    pub el_sync_finished: bool,
    pub need_fcu_call_backup_unsafe_reorg: bool,
}
The chain state viewed by the engine controller.

Fields

sync_state: EngineSyncState

The sync state of the engine.

el_sync_finished: bool

Whether or not the EL has finished syncing.

need_fcu_call_backup_unsafe_reorg: bool

Track when the rollup node changes the forkchoice to restore previous known unsafe chain. e.g. Unsafe Reorg caused by Invalid span batch. This update does not retry except engine returns non-input error because engine may forgot backupUnsafeHead or backupUnsafeHead is not part of the chain.

Implementations

Source

impl EngineState

pub fn needs_consolidation(&self) -> bool

Returns if consolidation is needed.

Consolidation is only performed by a rollup node when the unsafe head is ahead of the safe head. When the two are equal, consolidation isn’t required and the crate::BuildTask can be used to build the block.