pub struct ForkchoiceTask {
pub client: Arc<EngineClient>,
pub rollup: Arc<RollupConfig>,
pub envelope: Option<OpAttributesWithParent>,
pub state_update: EngineSyncStateUpdate,
}Expand description
The ForkchoiceTask executes an engine_forkchoiceUpdated call with the current
EngineState’s forkchoice, and no payload attributes.
Fields
client: Arc<EngineClient>The engine client.
rollup: Arc<RollupConfig>The rollup config.
envelope: Option<OpAttributesWithParent>Optional payload attributes to be used for the forkchoice update.
state_update: EngineSyncStateUpdateThe sync state update to apply to the engine state.
Implementations
Sourceimpl ForkchoiceTask
impl ForkchoiceTask
Sourcepub const fn new(
client: Arc<EngineClient>,
rollup: Arc<RollupConfig>,
state_update: EngineSyncStateUpdate,
payload_attributes: Option<OpAttributesWithParent>,
) -> Self
pub const fn new( client: Arc<EngineClient>, rollup: Arc<RollupConfig>, state_update: EngineSyncStateUpdate, payload_attributes: Option<OpAttributesWithParent>, ) -> Self
Creates a new ForkchoiceTask.