pub type EngineQuerySender = Sender<EngineQueries>;Expand description
The type of data that can be requested from the engine.
Aliased Type
pub struct EngineQuerySender { /* private fields */ }pub type EngineQuerySender = Sender<EngineQueries>;The type of data that can be requested from the engine.
pub struct EngineQuerySender { /* private fields */ }