pub enum AttributesMatch {
Match,
Mismatch(AttributesMismatch),
}Expand description
Result of validating payload attributes against an execution layer block.
Used to verify that proposed payload attributes match the actual executed block, ensuring consistency between the rollup derivation process and execution layer. Validation includes withdrawals, transactions, fees, and other block properties.
Examples
ⓘ
use kona_engine::AttributesMatch;
use kona_genesis::RollupConfig;
use kona_protocol::OpAttributesWithParent;
let config = RollupConfig::default();
let match_result = AttributesMatch::check_withdrawals(&config, &attributes, &block);
if match_result.is_match() {
println!("Attributes are valid for this block");
}Variants
Match
The payload attributes are consistent with the block.
Mismatch(AttributesMismatch)
The attributes do not match the block (contains mismatch details).
Implementations
Sourceimpl AttributesMatch
impl AttributesMatch
Sourcepub const fn is_mismatch(&self) -> bool
pub const fn is_mismatch(&self) -> bool
Returns true if the attributes do not match the block.
Sourcepub fn check_withdrawals(
config: &RollupConfig,
attributes: &OpAttributesWithParent,
block: &Block<Transaction>,
) -> Self
pub fn check_withdrawals( config: &RollupConfig, attributes: &OpAttributesWithParent, block: &Block<Transaction>, ) -> Self
Checks that withdrawals for a block and attributes match.
Sourcepub fn check(
config: &RollupConfig,
attributes: &OpAttributesWithParent,
block: &Block<Transaction>,
) -> Self
pub fn check( config: &RollupConfig, attributes: &OpAttributesWithParent, block: &Block<Transaction>, ) -> Self
Checks if the specified OpAttributesWithParent matches the specified Block.
Returns AttributesMatch::Match if they match, otherwise returns
AttributesMatch::Mismatch.