pub enum EngineQueries {
Config(Sender<RollupConfig>),
State(Sender<EngineState>),
OutputAtBlock {
block: BlockNumberOrTag,
sender: Sender<(L2BlockInfo, OutputRoot, EngineState)>,
},
StateReceiver(Sender<Receiver<EngineState>>),
}Expand description
Returns the full engine state.
Variants
Config(Sender<RollupConfig>)
Returns the rollup config.
State(Sender<EngineState>)
Returns current L2 engine state information.
OutputAtBlock
Returns the L2 output at the specified block with a tuple of the block info and associated engine state.
Fields

block: BlockNumberOrTagThe block number or tag of the block to retrieve the output for.

sender: Sender<(L2BlockInfo, OutputRoot, EngineState)>A channel to send back the output and engine state.
StateReceiver(Sender<Receiver<EngineState>>)
Returns a subscription to the updates of the engine state.
Implementations
Sourceimpl EngineQueries
impl EngineQueries
Sourcepub async fn handle(
self,
state_recv: &Receiver<EngineState>,
client: &Arc<EngineClient>,
rollup_config: &Arc<RollupConfig>,
) -> Result<(), EngineQueriesError>
pub async fn handle( self, state_recv: &Receiver<EngineState>, client: &Arc<EngineClient>, rollup_config: &Arc<RollupConfig>, ) -> Result<(), EngineQueriesError>
Handles the engine query request.