pub struct BuildTask {
pub engine: Arc<EngineClient>,
pub cfg: Arc<RollupConfig>,
pub attributes: OpAttributesWithParent,
pub is_attributes_derived: bool,
pub payload_tx: Option<Sender<OpExecutionPayloadEnvelope>>,
}Expand description
The BuildTask is responsible for building new blocks and importing them via the engine API.
Fields
engine: Arc<EngineClient>The engine API client.
cfg: Arc<RollupConfig>The RollupConfig.
attributes: OpAttributesWithParentThe OpAttributesWithParent to instruct the execution layer to build.
is_attributes_derived: boolWhether or not the payload was derived, or created by the sequencer.
payload_tx: Option<Sender<OpExecutionPayloadEnvelope>>An optional channel to send the built OpExecutionPayloadEnvelope to, after the block
has been built, imported, and canonicalized.
Implementations
Sourceimpl BuildTask
impl BuildTask
Sourcepub const fn new(
engine: Arc<EngineClient>,
cfg: Arc<RollupConfig>,
attributes: OpAttributesWithParent,
is_attributes_derived: bool,
payload_tx: Option<Sender<OpExecutionPayloadEnvelope>>,
) -> Self
pub const fn new( engine: Arc<EngineClient>, cfg: Arc<RollupConfig>, attributes: OpAttributesWithParent, is_attributes_derived: bool, payload_tx: Option<Sender<OpExecutionPayloadEnvelope>>, ) -> Self
Creates a new block building task.