pub struct ConsolidateTask {
pub client: Arc<EngineClient>,
pub cfg: Arc<RollupConfig>,
pub attributes: OpAttributesWithParent,
pub is_attributes_derived: bool,
}Expand description
The ConsolidateTask attempts to consolidate the engine state
using the specified payload attributes and the oldest unsafe head.
If consolidation fails, payload attributes processing is attempted using the BuildTask.
Fields
client: Arc<EngineClient>The engine client.
cfg: Arc<RollupConfig>The RollupConfig.
attributes: OpAttributesWithParentThe OpAttributesWithParent to instruct the execution layer to build.
is_attributes_derived: boolWhether or not the payload was derived, or created by the sequencer.
Implementations
Sourceimpl ConsolidateTask
impl ConsolidateTask
Sourcepub const fn new(
client: Arc<EngineClient>,
config: Arc<RollupConfig>,
attributes: OpAttributesWithParent,
is_attributes_derived: bool,
) -> Self
pub const fn new( client: Arc<EngineClient>, config: Arc<RollupConfig>, attributes: OpAttributesWithParent, is_attributes_derived: bool, ) -> Self
Creates a new ConsolidateTask.
Sourcepub async fn consolidate(
&self,
state: &mut EngineState,
) -> Result<(), ConsolidateTaskError>
pub async fn consolidate( &self, state: &mut EngineState, ) -> Result<(), ConsolidateTaskError>
Attempts consolidation on the engine state.