pub struct EngineSyncState { /* private fields */ }Expand description
The sync state of the engine.
Implementations
Sourceimpl EngineSyncState
impl EngineSyncState
Sourcepub const fn unsafe_head(&self) -> L2BlockInfo
pub const fn unsafe_head(&self) -> L2BlockInfo
Returns the current unsafe head.
Sourcepub const fn cross_unsafe_head(&self) -> L2BlockInfo
pub const fn cross_unsafe_head(&self) -> L2BlockInfo
Returns the current cross-verified unsafe head.
Sourcepub const fn local_safe_head(&self) -> L2BlockInfo
pub const fn local_safe_head(&self) -> L2BlockInfo
Returns the current local safe head.
Sourcepub const fn safe_head(&self) -> L2BlockInfo
pub const fn safe_head(&self) -> L2BlockInfo
Returns the current safe head.
Sourcepub const fn finalized_head(&self) -> L2BlockInfo
pub const fn finalized_head(&self) -> L2BlockInfo
Returns the current finalized head.
Sourcepub const fn create_forkchoice_state(&self) -> ForkchoiceState
pub const fn create_forkchoice_state(&self) -> ForkchoiceState
Creates a ForkchoiceState
head_block=unsafe_headsafe_block=safe_headfinalized_block=finalized_head
If the block info is not yet available, the default values are used.
Sourcepub fn apply_update(self, sync_state_update: EngineSyncStateUpdate) -> Self
pub fn apply_update(self, sync_state_update: EngineSyncStateUpdate) -> Self
Applies the update to the provided sync state, using the current state values if the update is not specified. Returns the new sync state.