pub struct EngineSyncStateUpdate {
pub unsafe_head: Option<L2BlockInfo>,
pub cross_unsafe_head: Option<L2BlockInfo>,
pub local_safe_head: Option<L2BlockInfo>,
pub safe_head: Option<L2BlockInfo>,
pub finalized_head: Option<L2BlockInfo>,
}Expand description
Specifies how to update the sync state of the engine.
Fields
unsafe_head: Option<L2BlockInfo>Most recent block found on the p2p network
cross_unsafe_head: Option<L2BlockInfo>Cross-verified unsafe head, always equal to the unsafe head pre-interop
local_safe_head: Option<L2BlockInfo>Derived from L1, and known to be a completed span-batch, but not cross-verified yet.
safe_head: Option<L2BlockInfo>Derived from L1 and cross-verified to have cross-safe dependencies.
finalized_head: Option<L2BlockInfo>Derived from finalized L1 data, and cross-verified to only have finalized dependencies.