pub struct Metrics;Expand description
Container for metrics.
Implementations
Sourceimpl Metrics
impl Metrics
Sourcepub const BLOCK_LABELS: &str = "kona_node_block_labels"
pub const BLOCK_LABELS: &str = "kona_node_block_labels"
Identifier for the gauge that tracks block labels.
Sourcepub const UNSAFE_BLOCK_LABEL: &str = "unsafe"
pub const UNSAFE_BLOCK_LABEL: &str = "unsafe"
Unsafe block label.
Sourcepub const CROSS_UNSAFE_BLOCK_LABEL: &str = "cross-unsafe"
pub const CROSS_UNSAFE_BLOCK_LABEL: &str = "cross-unsafe"
Cross-unsafe block label.
Sourcepub const LOCAL_SAFE_BLOCK_LABEL: &str = "local-safe"
pub const LOCAL_SAFE_BLOCK_LABEL: &str = "local-safe"
Local-safe block label.
Sourcepub const SAFE_BLOCK_LABEL: &str = "safe"
pub const SAFE_BLOCK_LABEL: &str = "safe"
Safe block label.
Sourcepub const FINALIZED_BLOCK_LABEL: &str = "finalized"
pub const FINALIZED_BLOCK_LABEL: &str = "finalized"
Finalized block label.
Sourcepub const ENGINE_TASK_COUNT: &str = "kona_node_engine_task_count"
pub const ENGINE_TASK_COUNT: &str = "kona_node_engine_task_count"
Identifier for the counter that records engine task counts.
Sourcepub const INSERT_TASK_LABEL: &str = "insert"
pub const INSERT_TASK_LABEL: &str = "insert"
Insert task label.
Sourcepub const CONSOLIDATE_TASK_LABEL: &str = "consolidate"
pub const CONSOLIDATE_TASK_LABEL: &str = "consolidate"
Consolidate task label.
Sourcepub const FORKCHOICE_TASK_LABEL: &str = "forkchoice-update"
pub const FORKCHOICE_TASK_LABEL: &str = "forkchoice-update"
Forkchoice task label.
Sourcepub const BUILD_TASK_LABEL: &str = "build"
pub const BUILD_TASK_LABEL: &str = "build"
Build task label.
Sourcepub const FINALIZE_TASK_LABEL: &str = "finalize"
pub const FINALIZE_TASK_LABEL: &str = "finalize"
Finalize task label.
Sourcepub const ENGINE_METHOD_REQUEST_DURATION: &str = "kona_node_engine_method_request_duration"
pub const ENGINE_METHOD_REQUEST_DURATION: &str = "kona_node_engine_method_request_duration"
Identifier for the histogram that tracks engine method call time.
Sourcepub const FORKCHOICE_UPDATE_METHOD: &str = "engine_forkchoiceUpdated"
pub const FORKCHOICE_UPDATE_METHOD: &str = "engine_forkchoiceUpdated"
engine_forkchoiceUpdatedV<N> label
Sourcepub const NEW_PAYLOAD_METHOD: &str = "engine_newPayload"
pub const NEW_PAYLOAD_METHOD: &str = "engine_newPayload"
engine_newPayloadV<N> label.
Sourcepub const GET_PAYLOAD_METHOD: &str = "engine_getPayload"
pub const GET_PAYLOAD_METHOD: &str = "engine_getPayload"
engine_getPayloadV<N> label.
Sourcepub const ENGINE_RESET_COUNT: &str = "kona_node_engine_reset_count"
pub const ENGINE_RESET_COUNT: &str = "kona_node_engine_reset_count"
Identifier for the counter that tracks the number of times the engine has been reset.